@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -137,7 +137,7 @@ sub lint_prereqs {
         local $/;
         ~~<$fh>;
     };
-    return [200, "Not run (no-lint-prereqs)"] if $ct =~ /^;!no-lint-prereqs$/m;
+    return [200, "Not run (no-lint-prereqs)"] if $ct =~ /^;!no[_-]lint[_-]prereqs$/m;
 
     my $cfg = Config::IniFiles->new(-file => "dist.ini", -fallback => "ALL");
     $cfg or return [
@@ -161,7 +161,7 @@ sub lint_prereqs {
             $mods_from_ini{$param}   = $v unless $section =~ /assume-provided/;
             $assume_provided{$param} = $v if     $section =~ /assume-provided/;
             $assume_used{$param}     = $v if     $section =~ /assume-used/ ||
-                $cmt =~ /^;!lint-prereqs\s+assume-used\b/m;
+                $cmt =~ /^;!lint[_-]prereqs\s+assume-used\b/m;
         }
     }
     $log->tracef("mods_from_ini: %s", \%mods_from_ini);
@@ -315,7 +315,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.27 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-17.
+This document describes version 0.28 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -326,8 +326,9 @@ This document describes version 0.27 of App::LintPrereqs (from Perl distribution
 
 =head2 lint_prereqs(%args) -> [status, msg, result, meta]
 
-Check extraneous/missing prerequisites in dist.ini.
+{en_US Check extraneous/missing prerequisites in dist.ini}.
 
+{en_US 
 Check C<[Prereqs / *]> (as well as C<OSPrereqs>, C<Extras/lint-prereqs/Assume-*>)
 sections in your C<dist.ini> against what's actually being used in your Perl code
 (using C<Perl::PrereqScanner::Lite>) and what's in Perl core list of modules.
@@ -353,19 +354,23 @@ ignore them:
  [Extras / lint-prereqs / assume-provided]
  Qux::Quux=0
 
+}
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
 =item * B<lite> => I<bool> (default: 1)
 
-Use Perl::PrereqScanner::Lite instead of Perl::PrereqScanner.
+{en_US Use Perl::PrereqScanner::Lite instead of Perl::PrereqScanner}.
 
+{en_US 
 Lite is faster but it might still miss detecting some modules.
+}
 
 =item * B<perl_version> => I<str>
 
-Perl version to use (overrides scan_prereqs/dist.ini).
+{en_US Perl version to use (overrides scan_prereqs/dist.ini)}.
 
 =back
 
